(function (factory) {
    if (typeof module === 'object' && typeof module.exports === 'object') {
        var v = factory(require, exports); if (v !== undefined) module.exports = v;
    }
    else if (typeof define === 'function' && define.amd) {
        define(["require", "exports", './isObject'], factory);
    }
})(function (require, exports) {
    "use strict";
    /*
    * @Author:				taoqf
    * @Date:				2016-06-15 11:59:02
    * @Last Modified by:	taoqf
    * @Last Modified time:	2016-06-17 15:54:38
    * @CopyRight			飞道科技
    */
    const isObject_1 = require('./isObject');
    /** `Object#toString` result references. */
    const funcTag = '[object Function]', genTag = '[object GeneratorFunction]';
    /** Used for built-in method references. */
    const objectProto = Object.prototype;
    /**
     * Used to resolve the
     * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
     * of values.
     */
    const objectToString = objectProto.toString;
    /**
     * @module @feidao/core/lodash/isFunction
     * @example
     * import isFunction from '@feidao/core/lodash/isFunction';
     *
     * isFunction(_);
     * // => true
     *
     * isFunction(/abc/);
     * @see _.isFunction
    */
    /**
     * Checks if `value` is classified as a `Function` object.
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified,
     *  else `false`.
     * @example
     *
     * _.isFunction(_);
     * // => true
     *
     * _.isFunction(/abc/);
     * // => false
     */
    function isFunction(value) {
        // The use of `Object#toString` avoids issues with the `typeof` operator
        // in Safari 8 which returns 'object' for typed array and weak map constructors,
        // and PhantomJS 1.9 which returns 'function' for `NodeList` instances.
        var tag = isObject_1.default(value) ? objectToString.call(value) : '';
        return tag == funcTag || tag == genTag;
    }
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = isFunction;
});
