(function (factory) {
    if (typeof module === 'object' && typeof module.exports === 'object') {
        var v = factory(require, exports); if (v !== undefined) module.exports = v;
    }
    else if (typeof define === 'function' && define.amd) {
        define(["require", "exports", './_baseIsNative', './_coreJsData', './isFunction', './stubFalse'], factory);
    }
})(function (require, exports) {
    "use strict";
    /*
    * @Author:				taoqf
    * @Date:				2016-06-15 11:59:02
    * @Last Modified by:	taoqf
    * @Last Modified time:	2016-06-17 15:54:29
    * @CopyRight			飞道科技
    */
    const _baseIsNative_1 = require('./_baseIsNative');
    const _coreJsData_1 = require('./_coreJsData');
    const isFunction_1 = require('./isFunction');
    const stubFalse_1 = require('./stubFalse');
    /**
     * Checks if `func` is capable of being masked.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `func` is maskable, else `false`.
     */
    const isMaskable = _coreJsData_1.default ? isFunction_1.default : stubFalse_1.default;
    /**
     * Checks if `value` is a pristine native function.
     *
     * **Note:** This method can't reliably detect native functions in the
     * presence of the `core-js` package because `core-js` circumvents this kind
     * of detection. Despite multiple requests, the `core-js` maintainer has made
     * it clear: any attempt to fix the detection will be obstructed. As a result,
     * we're left with little choice but to throw an error. Unfortunately, this
     * also affects packages, like [babel-polyfill](https://www.npmjs.com/package/babel-polyfill),
     * which rely on `core-js`.
     *
     * @static
     * @memberOf _
     * @since 3.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a native function,
     *  else `false`.
     * @example
     *
     * _.isNative(Array.prototype.push);
     * // => true
     *
     * _.isNative(_);
     * // => false
     */
    function isNative(value) {
        if (isMaskable(value)) {
            throw new Error('This method is not supported with `core-js`. Try https://github.com/es-shims.');
        }
        return _baseIsNative_1.default(value);
    }
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = isNative;
});
