(function (factory) {
    if (typeof module === 'object' && typeof module.exports === 'object') {
        var v = factory(require, exports); if (v !== undefined) module.exports = v;
    }
    else if (typeof define === 'function' && define.amd) {
        define(["require", "exports", './isArray', './isObjectLike'], factory);
    }
})(function (require, exports) {
    "use strict";
    /*
    * @Author:				taoqf
    * @Date:				2016-06-15 11:59:02
    * @Last Modified by:	taoqf
    * @Last Modified time:	2016-06-17 15:54:31
    * @CopyRight			飞道科技
    */
    const isArray_1 = require('./isArray');
    const isObjectLike_1 = require('./isObjectLike');
    /** `Object#toString` result references. */
    const stringTag = '[object String]';
    /** Used for built-in method references. */
    const objectProto = Object.prototype;
    /**
     * Used to resolve the
     * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
     * of values.
     */
    const objectToString = objectProto.toString;
    /**
     * @module @feidao/core/lodash/isString
     * @example
     * import isString from '@feidao/core/lodash/isString';
     *
     * isString('abc');
     * // => true
     *
     * isString(1);
     * // => false
     * @see _.isString
    */
    /**
     * Checks if `value` is classified as a `String` primitive or object.
     *
     * @static
     * @since 0.1.0
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is correctly classified,
     *  else `false`.
     * @example
     *
     * _.isString('abc');
     * // => true
     *
     * _.isString(1);
     * // => false
     */
    function isString(value) {
        return typeof value == 'string' ||
            (!isArray_1.default(value) && isObjectLike_1.default(value) && objectToString.call(value) == stringTag);
    }
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.default = isString;
});
